@@ -1,4 +1,4 @@
-'sunrise.set' <- function(lat, long, date, timezone="UTC", 		  num.days=1){
+`sunrise.set` <- function(lat, long, date, timezone="UTC", 		  num.days=1){
       #this needs to be long lat#
       lat.long <- matrix(c(long, lat), nrow=1)
       day <- as.POSIXct(date, tz=timezone)
